function[res]=applyfda1(saisir,fda1type,actual_group)
%applyfda1		- application of factorial discriminant analysis on PCA scores 
%function[res]=applyfda1(X,fdatype,(actual_group))
%
%Input arguments:
%===============
%X: Saisir matrix of predictive variables (n x p)
%fdatype : structure, output of function "fda1" 
%actual_group (optional)(n x 1): SAISIR vector indicating the membership of
%the observations. A same number indicates that these observations belong to
%the same group. 
%
%Output argument:
%===============
%res with fields
%datafactor : discriminant scores (n rows) 
%predicted_group: number indicating the prediction in each group
%If actual_group si given, the field "confusion" gives the confusion matrix
%row: actual group, columns: predicted by the "fda1"
%
% Typical example:
%================
%(calibration data in "calibration_data", group in "qualitative_group",
%Unknown data in "unknown_data");
%%Building the model
%p=pca(calibration_data);
%fdatype=fda1(p, qualitative_group, 10, 5)
%%Applying the model 
%res=applyfda1(unknown_data,fdatype);
%See also : fda1, maha3, maha6, plsda, pca 

[n,p]=size(saisir.d);
centred=saisir.d-ones(n,1)*fda1type.average.d;
S=centred*fda1type.beta.d;
J=fda1type.centroidfactor.d;
ngroup=size(J,1);
predict=zeros(n,1);
for j=1:n
   	if(mod(j,10000)==0)
        disp([j n]);
    end
    delta=J-ones(ngroup,1)*S(j,:);   
      dist=sum((delta.*delta)',1);   
      [aux1 predicted_group]=min(dist);
   	predict(j)=predicted_group;   
 end      
 res.datafactor.d=S;
 res.datafactor.i=saisir.i;
 res.datafactor.v=fda1type.beta.v;
 res.predicted_group.d=predict;
 res.predicted_group.i=saisir.i;
 res.predicted_group.v='predicted group';
if(nargin>2)
	confusion=zeros(ngroup,ngroup);
	for i=1:n
   	confusion(actual_group.d(i),predict(i))=confusion(actual_group.d(i),predict(i))+1;
	end
res.confusion=confusion;
%res.nclassed=sum(predict'==actual_group.d)/n;
end
