function[coordsup]=applypca(pcatype,saisir)
%applypca     - computes the scores of supplementary observations
%function [supscores]=applypca(pcatype, X)
%assess the scores of supplementary observations
%
%Input arguments:
%===============
%pcatype: (structure) output argument of functions "pca","normed_pca", or
%"covariance_pca"
%X      : SAISIR matrix of supplementary observations
%
%Output argument:
%===============
%supscores : SAISIR matrix of scores of X
%
%Typical example
%===============
%p=pca(spectra);%% PCA
%supscores=applypca(p,supplementary_spectra); 
%map(supscores,1,2); 
%
%The number of columns of X must be compatible with pcatype.  
%If "normed_pca" was applied, X is divided by the standard deviations of 
% the principal observations prior to projection 

[n,p]=size(saisir.d);
if(p~=size(pcatype.average.d))
   help pcr;
   error('irrelevant dimensions in input data');
end   



if(isfield(pcatype,'nobservation'));%% for the case function cumulate_covariance/covariance_pca
aux=sqrt(pcatype.nobservation);
else
    [n1,p1]=size(pcatype.score.d);
    aux=sqrt(n1);
end


if(isfield(pcatype,'std'));
    
    saisir.d=saisir.d./(ones(n,1)*pcatype.std.d);

end

centred=saisir.d-ones(n,1)*pcatype.average.d;


coordsup.d=(centred*pcatype.eigenvec.d)/aux;
% identifiers
coordsup.i=saisir.i;
coordsup.v=pcatype.eigenvec.v;
