function[res]=applyplsda(x,model,actual_group)
%applyplsda - Applies pls discriminant analysis after model assessment using plsda
%function[res]=applyplsda(X,plsdatype,(actual_group))
%return the predicted group on (unknown data x)
%
%Input arguments:
%===============
%X : SAISIR matrix of predictive variables
%plsdatype: structure returned by function 'plsda'
%actual_group (optional): SAISIR vector of observed groups. 
%Observations with the same group number belong to the same group. 
%
%Ouput argument:
%==============
%res with fields:
%confusion1: matrix of confusion, method 1 (if "actual_group"
%defined)
%ncorrect1: Number of correct classifications, method 1 (if "actual_group"
%defined)
%predgroup1: predicted group (method1)
%confusion: matrix of confusion, method 0 (if "actual_group"
%defined) 
%ncorrect: Number of correct classifications, method 1 (if "actual_group"
%defined)
%predgroup: predicted group (method 0)
%
%Method 1: (attribution to index of max of predicted Y)
%Method 0:  (shortest Mahalanobis distance calculated on PLS scores);

group=size(model.linear.v,1);
[n,p]=size(x.d);
%aux=ones(n,1)*model.linear0.d;
aux1=x.d*model.linear.d+ones(n,1)*model.linear0.d;% prediction of scores T
[bid index]=min(aux1');
pred.d=index';
pred.i=x.i;
pred.v='predicted group (according to Mahalanobis distance on t)';

if(nargin>2)
	ngroup=max(actual_group.d);
    confusion=zeros(ngroup,ngroup);
	for i=1:n
   	confusion(actual_group.d(i),pred.d(i))=confusion(actual_group.d(i),pred.d(i))+1;
	end
res.confusion1=confusion;
res.ncorrect1=sum(pred.d==actual_group.d);
end
res.predgroup1=pred;

%aux=ones(n,1)*model.beta0.d;
aux1=x.d*model.beta.d+ones(n,1)*model.beta0.d;%% predictions of indicators
%================
[dummy,index]=max(aux1');
classed=index';
if(nargin>2)
    confusion=zeros(ngroup,ngroup);
    for i=1:n
   confusion(actual_group.d(i),classed(i))=confusion(actual_group.d(i),classed(i))+1;
end
res.ncorrect=trace(confusion);
res.confusion=confusion;
end
res.predgroup.d=classed;
res.predgroup.i=x.i;
res.predgroup.v='predicted group (according to max of pred y)';
res.info=model.info;
%=================
