function [res_calib]=comdim_calib_V6(col,ndim,threshold)
%comdim			- Finding common dimensions in multitable data (saisir format)
% function[res_calib]=comdim_calib_V6(collection,(ndim),(threshold))
%
%Input arguments:
%---------------
%collection : vector of saisir files (the numbers "nrow" of rows in each table must be equal) . 
%ndim : number of common dimensions
%threshold (optional): if the "difference of fit"<threshold then break the
%iterative loop 
%
%Output arguments:
%-----------------
%res_calib with fields:
% Q : Global scores_calib (nrow x ndim)
% P : Global loadings calculated from Q and tables (nvars x ndim)
% P_Loc : Structure with ntable of Local loadings in matrices of (local vars x ndim)
% T : Structure with ntable of Local scores_calib calculated from local Loadings and tables (nrow x ndim)
% saliences : weight of the original tables in each dimension (ntable x ndim)
% explained : percentage explanation given by each dimension (1 x ndim)
%
% NORM : ntable norms of the tables (1 x 1)
% MEAN : ntable means of tables (1 x nvars)
% SingVal : vector of singular values (1 x ndim)
%
%Method published by  E.M. Qannari, I. Wakeling, P. Courcoux and H. J. H. MacFie
%in Food quality and Preference 11 (2000) 151-154
%
%typical example (suppose 3 SAISIR matrices
%"spectra1","spectra2","spectra3")
%collection(1)=spectra1; collection(2)=spectra2; collection(3)=spectra3
%[res_calib]=comdim_calib_DB(collection,ndim);
%map(res_calib.Q,1,2);%% looking at the ComDim compromise scores
%figure;
%map(res_calib.T,1,2);%% looking at the calculated global scores
%figure;
%map(res_calib.saliences,1,2);%% looking at the weights

ntable=size(col,2);
if(nargin<3)
   threshold=1E-10;
end;

if(nargin<2)
   ndim=ntable;
end;

for(i=1:ntable)
   s{i}=col(i).d;
end

[Q.d, saliences.d, explained.d, SingVal.d]=xcomdim_V5(s,threshold,ndim);

for i=1:ndim
   chaine=['D' num2str(i) '        '];
   bid(i,:)=chaine(1:6);
end

for i=1:ntable
   chaine1=['t' num2str(i) '        '];
   bid1(i,:)=chaine1(1:6);
end

Q.i=col(1).i;
Q.v=bid;

SingVal.v=bid;
SingVal.i='Singular value';

%% Calculate Normalised concatenated Xs ('Calib') from col
% Calculate concatenated CD loadings
% Reorganise Loadings - 1 matrix / LV

clear L_CD_Vec Calib;
L_CD_Vec=[];
Calib=[];
nCalib= size(col(1,1).d,1);

%centrage et normalisation tables 'calibration' (col)
for i=1:ntable

    [X_Normed, Norm(i).d, Mean(i).d]=Normalise_DB(col(i).d); % MS
    res_calib.NORM(i).d= Norm(i).d;
    res_calib.MEAN(i).d= Mean(i).d;

    temp_tabCalib{i}.d=X_Normed;
%     Calib=[Calib,temp_tabCalib(i).d];

end

%T=zeros(nCalib,ndim);
for j=1:ndim
    temp_vec=[];
    temp_mat=[];
    for i=1:ntable

        temp_mat=[temp_mat;temp_tabCalib{i}.d']; % X blocs concatns
        
        temp=temp_tabCalib{i}.d'*Q.d(:,j); % Loadings "locaux" calculs
        L_CD{i}(:,j)=temp;

        temp_vec=[temp_vec;temp(:)]; % Loadings "locaux" concatns

        T{i}(:,j)=temp_tabCalib{i}.d*temp*inv(temp'*temp); % Scores locaux

        %T.d(:,j)=sumpred*comdim_calib.Q.d(:,j); % DB, 03.04.2014, Aprs SVD, les Scores de XX'= les Loadings de XX'
        temp_tabCalib{i}.d=temp_tabCalib{i}.d-Q.d(:,j)*Q.d(:,j)'*temp_tabCalib{i}.d;
        
    end
    
    L_CD_Vec(:,j)=temp_mat*Q.d(:,j); % Loadings "globaux"
end

%% Output

res_calib.Q=Q;

res_calib.T.d=T;
res_calib.T.i=Q.i;% samples
res_calib.T.v=Q.v;% dimensions

res_calib.P.d= L_CD_Vec;
res_calib.P.i=[1:size(L_CD_Vec,1)]';% numbers of all variables;
res_calib.P.v=Q.v;% dimension;

res_calib.P_Loc.d= L_CD;
res_calib.P_Loc.i=1;
res_calib.P_Loc.v=Q.v; % dimension;

res_calib.SingVal=SingVal; % DB, 13.03.2014

saliences.i=bid1;% tables
saliences.v=Q.v;% dimensions
res_calib.saliences=saliences;

explained.i='% explained';
explained.v=Q.v;% dimensions
res_calib.explained=explained;

