function[res]=crossfda1(saisir,group,among,maxvar,ntest)
%crossfda1		- validation on discrimination according to fda1 (directly on data) 
%function[res]=crossfda1(X,group,among,maxvar,ntest)
%
%input arguments
%===============
%X: Saisir data matrix (n x p)
%group:Saisir vector of group (integer, n x 1).Two observations belonging
%to the same group have the same group number.
%among: maximum rank of the PC scores entered in the model (see "fda1" for
%details)
%maxvar: (integer) maximal number of scores entered in the model
%ntest: (integer) number of observation in each group in the validation
%set
%
%ouput arguments:
%===============
%res with fields
%fdatype: fdatype built up with the calibration set (see function "fda1")
%verification:
%   with fields
%   datafactor: discriminant scores of the validation set
%   predicted_group: in the validation set
%   confusion: confusion matrix of the validation set (rows: actual group;
%   columns: predicted group)
%
%The function applies "fda1" by dividing the sample in X into calibration and validation set
%"ntest" observations in each group are randomly (with no repeat) placed in test group.
%
%%typical example:
%g=create_group1(wheat,2,3);%% creation of the vector of group number
%res=crossfda1(wheat,g,10,5,5);
%res.validation.confusion;%% confusion matrix in validation
%%colored_map1(res.validation.datafactor,1,2,2,3); %% looking at the
%%discriminant biplot of the validation set
%
maxgroup=max(group.d);
selected=zeros(1,size(saisir.d,1));
aux=1:size(saisir.d,1);
confusion.cal=zeros(maxgroup,maxgroup);
confusion.val=zeros(maxgroup,maxgroup);
for i=1:maxgroup
   nsample=sum(group.d==i);
   %suite=i
   aux1=aux(group.d==i);
   found=0;
   while found<ntest
        number=uint32(random('Uniform',1,nsample+0.5));
   	if(selected(1,aux1(number))==0)
      	selected(1,aux1(number))=1;
      	found=found+1;
   	end;
   end;
end;


cal=deleterow(saisir,(selected==1));
val=selectrow(saisir,(selected==1));
cal_group=deleterow(group,(selected==1));
val_group=selectrow(group,(selected==1));
pcatype=pca(cal);
fdatype=fda1(pcatype,cal_group,among, maxvar);
res1=applyfda1(val,fdatype,val_group);
res.fdatype=fdatype;
res.verification=res1;
