function[res]=crossplsda(x,group,dim,selected)
%crossplsda - validation on PLS discriminant analysis
%function[res]=crossplsda(X,group,dim,selected)
%
%Input arguments:
%===============
%X:SAISIR matrix of predictive data (n x p)
%group:SAISIR vector of group numbers (n x 1). A same number indicates that
%the observations belong to the sdame group
%dim: maximum number of PLS dimensions
%selected:matlab VECTOR with 0= calibration sample, 1= verification sample
%
%Output argument:
%===============
%res with fields:
%confusion1: confusion matrix of the calibration set , method 1
%ncorrect1: number of correctly classified obs. in calibration, method1
%nscorrect1: number of correctly classified obs. in validation, method1
%sconfusion1: confusion matrix of the validation set , method 1
%confusion: confusion matrix of the calibration set , method 0
%ncorrect: number of correctly classified obs. in calibration, method 0
%nscorrect: number of correctly classified obs. in validation, method 0
%sconfusion: number of correctly classified obs. in validation, method 0
%info: ' no index: max of predicted Y; 1: mahalanobis distance on latent variables t'
%
%The function divides the data collection into a calibration set
%(selected=0) and a validation set (selected = 1)
%The function "plsda" is applied on the calibration set, and tested on the validation set.
%
%Two strategies for attributing a group to each observation are tested:
%Method 0 (no index): the observations are classified in the group for
%which the predicted indicator variable is the highest.
%Method 1: (preferable) linear discrimination on the PLS scores
%
%see also:"plsda", "applyplsda"

ngroup=max(group.d);
[n,p]=size(x.d);
xcal=selectrow(x,selected==0);
gcal=selectrow(group,selected==0);
xval=selectrow(x,selected==1);
gval=selectrow(group,selected==1);
model=plsda(xcal,gcal,dim);
xres=applyplsda(xval,model,gval);
confusion1=zeros(ngroup,ngroup);
%for i=1:size(xval.d,1)
%   confusion1(gval.d(i),res.predgroup1.d(i))=confusion1(gval.d(i),res.predgroup1.d(i)) + 1;
%end
res.confusion1=model.confusion1;
res.ncorrect1=model.ncorrect1;
res.nscorrect1=xres.ncorrect1;
res.sconfusion1=xres.confusion1;

res.confusion=model.confusion;
res.ncorrect=model.ncorrect;
res.nscorrect=xres.ncorrect;
res.sconfusion=xres.confusion;
res.info=model.info;
