function[res]=crossvalpls(x,y,ndim,selected)
%crossvalpls			- validation of pls with up to ndim dimensions. 
%function [res]=crossvalpls(X,y,ndim,selected)
%
% Input args: 
%===========
%X: predictive data n x p
%y: Variable to be predicted n x 1
%ndim: maximal number of dimensions in the PLS model 
%selected: Matlab vector n x 1 (0= obs in calibration; 1 in validation)
%
% Output args
%============
% res with fields
%---calibration: calibration results with fields
%   BETA: regression coefficients (p x ndim)
%   BETA0: intercept (p x 1)
%   PREDY: predicted y in calibration (n x ndim)
%   T: scores PLS  (n x ndim)
%   RMSEC: Root mean square of calibration (1 x ndim)
%   r2: determination coefficient (yobs/ypred) (1 x ndim)
%---validation : validation  results with fields
%   PREDY: predicted y in validation (n x ndim)
%   RMSEV: Root mean square error of validation (1 x ndim )
%   r2: determination coefficient (yobs/ypred) (1 x ndim)
%   OBSY: observed y in validation (number of rows=number of obs in
%   validation)
%
%See also: "crossvalpls1a"
%Note:
% "crossvalpls" is faster than "crossvalpls1a" but gives less information (for
% example the PLS scores in validation and the loadings in calibration are not given here))


nind=size(x.d,1);
nend=nind;
%disp(['dimension ' num2str(ndim)]);
%disp(['test ' num2str(i) ' among ' num2str(ntest) ]);
%selected=random_select(nind,inval);
[xval, xcal]=splitrow(x,selected==1);
clear x;%% to reduce the amount of memory
[yval, ycal]=splitrow(y,selected==1);
clear y; %% to reduce the amount of memory
%plsmodel=saisirpls(xcal,ycal,ndim);
%plsmodel=basic_pls(xcal,ycal,ndim);
plsmodel=quickpls(xcal,ycal,ndim);
[res1]=applypls(xval,plsmodel,yval);
res1.OBSY=yval;
res.calibration=plsmodel;
res.validation=res1;
