function[res]=crossvalpls1a(x,y,ndim,selected)
%crossvalpls1a			- crossvalidation of pls with up to ndim dimensions. 
%function [res]=crossvalpls1a(X,y,ndim,selected)
% Input args: 
%===========
%X: predictive data n x p
%y: Variable to be predicted n x 1
%ndim: maximal number of dimensions in the PLS model 
%selected: Matlab vector n x 1 (0= obs in calibration; 1 in validation)
% Output args
%============
% res with fields
%---calibration: calibration results with fields
% res with fields:
%   T: PLS scores (n x ndim) 
%   P:PLS loadings such as X = TP + residuals (ndim x p) 
%   beta:  final regression coefficients with ndim dimensions (p x 1)
%   beta0: final interecpt value (number)
%   meanx: mean of X (1 x p)
%   meany: mean of y (numbe)
%   predy: predicted y with ndim dimensions (n x 1)
%   error: Root mean square error of the model with ndim dimensions (number)
%   corcoef: correlation coefficient r between observed and predicted values
%   in the model with ndim dimensions
%   BETA: regression coefficients for the ndim models (p x ndim)
%   BETA0: intercepts of the ndim models (ndim x 1) 
%   loadings: pls loadings such as T=X*loadings (with X centred) (p x ndim)  
%   Q: Q value such as y = TQ + residual (ndim x 1) 
%   PREDY: predicted y values up to ndim dimensions (n x ndim)
%   RMSEC: Root mean square error of predicttion up to ndim dimensions (1 x
%   ndim)
%   r2: determination coefficient between observed and predicted values (1 x
%   ndim) 
%---validation : validation  results with fields
%   PREDY: predicted y in validation (n x ndim)
%   RMSEV: Root mean square error of validation (1 x ndim )
%   r2: determination coefficient (yobs/ypred) (1 x ndim)
%   T : PLS scores in validation
%   OBSY: observed y in validation (number of rows=number of obs in
%   validation)
%
%See also: "crossvalpls"
%Note:
% crossvalpls1a is slower than crossvalpls but gives more information (for
% example the PLS scores in validation)

nind=size(x.d,1);
nend=nind;
%disp(['dimension ' num2str(ndim)]);
%disp(['test ' num2str(i) ' among ' num2str(ntest) ]);
%selected=random_select(nind,inval);
[xval, xcal]=splitrow(x,selected==1);
clear x;%% to reduce the amount of memory
[yval, ycal]=splitrow(y,selected==1);
clear y; %% to reduce the amount of memory
%plsmodel=saisirpls(xcal,ycal,ndim);
plsmodel=basic_pls(xcal,ycal,ndim);
[res1]=applypls(xval,plsmodel,yval);
res1.OBSY=yval;
res.calibration=plsmodel;
res.validation=res1;
