function [covariance_type]=cumulate_covariance(x,covariance_type1);
%cumulate_covariance    - Covariance on huge data set
%function [covariance_type]=cumulate_covariance((X),(covariance_type1));
%This function is mainly useful for computing PCA on very large data sets
%
%Input arguments:
%---------------
%X: SAISIR matrix X (n x p) or [];
%covariance_type: (optional): output argument of the function "cumulate_covariance"
%
%Output argument:
%----------------
%covariance_type: either intermediary results in cumulating covariance
%or a structure containing covariance matrix (at completion)
%At completion, "covariance_type" has fields:
%covariance: matrix p x p of covariances
%average: average value of all the observations (1 x p)
%n: total number of observations involved in computing the covariance
%matrix
%
%if the second argument (covariance_type1) undefined, initiate the calculation of covariance, 
%If the two arguments are defined, cumulate the covariance
%if the first argument =[], finish the work
%
%A complete script must therefore be something like
%cov=cumulate_covariance(spectra_1);%% starting
%cov=cumulate_covariance(spectra_2,cov);%% cumulating values of matrix 1
%cov=cumulate_covariance(spectra_3,cov);%% cumulating values of matrix 2
%...
%cov=cumulate_covariance(spectra_k,cov);%% cumulating values of matrix k
%covariance_type=cumulate_covariance([],cov);%% finishing
%[pcatype]=covariance_pca(covariance_type,(ncomponent))
%score1=applypca(pcatype,spectra_1);%% projecting data from spectra_1 
%
%
%related function; "covariance_pca" (pca from covariance)

if(~isempty(x))
%cumulating the values 
    if(nargin==1)
        covariance_type.X_X=x.d'*x.d;
        covariance_type.SX=sum(x.d);
        covariance_type.n=size(x.d,1);
        covariance_type.v=x.v;   
     else
        covariance_type.X_X=x.d'*x.d+covariance_type1.X_X;
        covariance_type.SX=sum(x.d)+covariance_type1.SX;
        covariance_type.n=size(x.d,1)+covariance_type1.n;
        covariance_type.v=covariance_type1.v;
    end
else
% final calculation    
n=covariance_type1.n;
m=covariance_type1.SX/n;
%thisone=ones(n,1);
thisone=ones(size(covariance_type1.X_X,1),1);
covariance_type.d=covariance_type1.X_X/n-2*m'*m+(m'*thisone'*thisone*m)/n;
covariance_type.i=covariance_type1.v;
covariance_type.v=covariance_type1.v;
covariance_type.n=n;
covariance_type.average.d=m;
covariance_type.average.i='average';
covariance_type.average.v=covariance_type1.v;


% x=rand(20,5);
% test=matrix2saisir(x);
% cov=covmap(test,test);
% x_x=zeros(5,5);
% sx=zeros(1,5);
% [n,p]=size(x);
% for i=1:n
%     a=x(i,:);
%     sx=sx+a;
%     x_x=x_x+a'*a;
% end
% m=sx/n;
% thisone=ones(n,1);
% thiscov=x_x/20-2*m'*m+(m'*thisone'*thisone*m)/n;

end



