function[res]=dimcross_stepwise_regression(x,y,selected,Pthres,confidence)
%dimcross_stepwise_regression		- Tests models obtained from stepwise regression
%function[res]=dimcross_stepwise_regression(X,y,selected,Pthres,(confidence))
%Input arguments:
%X : SAISIR matrix of predictive variables (n x p)
%y : SAISIR vector of variable to be predicted (n x 1)
%selected: MATLAB vector (p elements). 0 = in the calibration set;
%1 = validation set
%Pthres: probability threshold of entering or discarding variable
%confidence: (optional): confidence interval for the correlation coefficient 
% ouput argument:
%res with fields
%calibration (see "stepwise_regression")
%validation (see "apply_stepwise_regression")
%validation has fields
%   predy: predicted y in validation for all the regression models
%   rmsev: root mean square error of validation (idem)
%   r2: determination coefficient between observed and predicted y
%   observed_y: vector of observed y values in the validation set. 
%
%The function divides the data set X and y in a calibration set and a
%validation set. The vector "selected" defines the division.
%The stepwise regression models are established on the calibration set
%and tested on the validation set. All the calculated models are tested,
%which gives as many columns of predicted y as the number models computed
%by stepwise_regression. 

if(nargin<5);confidence=0.05;end;

if(size(y.d,2)~=1)
   help dimcrosspls;
   error('y must have only one column');
end;   
[xcal, xval]=splitrow(x,selected==0);
[ycal, yval]=splitrow(y,selected==0);
res.calibration=stepwise_regression(xcal,ycal,Pthres,confidence);
res.validation=apply_stepwise_regression(res.calibration,xval,yval);
res.validation.observed_y=yval;