function[pcrres]=dimcrosspcr1(x,y,dimmax,selected)
%dimcrosspcr1			- validation of PCR (samples in validation are selected) 
%function [pcrres]=dimcrosspcr1(X,y,ndim,selected)
%
% Input arguments:
%=================
% X : SAISIR matrix of predictive variables (n x p)  
% y : SAISIR vector of variable to be predicted (n x 1) 
%ndim: max number of PCR dimensions tested
%selected: MATLAB vector of samples selected as calibration set (==0)
%and verification set (==1)
%
%Output arguments:
%================
%pcrres with fields 
%r2: determination coefficient between observed and predicted y (1 x ndim)
%predy: predicted y for all the dimensions tested ( n x ndim)
%rmsev: root mean square error of validation  for all the dimensions tested (1 x ndim) 
%obsy: observed y in the validation  set
%Components introduced in the order of the eigenvalues
%Remarks; 
%%1) The vector "selected" can be build randomly using the function 
%"random_select" 
%2)The biplot observed/predicted values can be displayed by the command
% "xy_plot" (for example
% "xy_plot(pcrres.obsy,1,pcrres.predy,3)"
% will show the PCR model with 3 dimensions. 



nval=sum(selected==1);
if(size(y.d,2)~=1)
   help dimcrosspcr;
   error('y must have only one column');
end;   
nind=size(x.d,1);
nend=nind;
[xval, xcal]=splitrow(x,(selected==1));
[yval, ycal]=splitrow(y,(selected==1));
pcrtype=pcr(xcal,ycal,dimmax);
crossvaly=applypcr(pcrtype, xval);
predy=crossvaly;
size(predy.d);
size(yval.d);
%size(ones(1,dimmax))

residual=predy.d-yval.d*ones(1,dimmax);
nend=size(yval.d,1);
rmsecv.d=sqrt(sum(residual.*residual)/nend);
rmsecv.i='RMSECV';
rmsecv.v=pcrtype.beta.i;
co=corrcoef([predy.d yval.d]);% J'EN SUIS LA (A VERIFIER)
if(size(co,1)>1)
   corr.d=co(1:dimmax,dimmax+1)';%
   corr.v=pcrtype.beta.i;
	corr.i='Correlation coefficient';
	pcrres.r2=corr;   
    pcrres.r2.d=corr.d.*corr.d;
end;
pcrres.predy=predy; pcrres.rmsecv=rmsecv; 
pcrres.obsy=yval;
pcrres.pcrtype=pcrtype;
