function ellipse_map(D,i,j,gr,centroid_variability,confidence,point_plot)
%ellipse_map    -  plots the ellipse confidence interval of groups
%function ellipse_map(X,col1,col2,gr,centroid_variability,(confidence),(point_plot))
%
%Input arguments:
%================
%   - X: data matrix
%   - col1, col2: represented columns
%   - gr: qualitative groups (referred as integer number)
%   - centroid_variability  : either 0 (variability of individual data
%   points), or 1 : variability of the centroid itself (default: 0)
%   confidence: P value of the confidence interval to be out of the ellipse (default: 0.05)      
%   point_plot: if point_plot ~=0 , plots also the individual points as
%   symbols (inactivated if centroid_variability set to 1)
%
%useful in discriminant analysis and related methods.


if(nargin<7)
    pointPlot=0;
else
    pointPlot=point_plot;
end

csize=15;
cSizePoint=6;
confi=0.05;
centr_var=0;
if(nargin>4)
    centr_var=centroid_variability;
end
if(nargin>5)
    confi=confidence;
else
    confi=0.05;
end
couleur=[0 0 0; 1 0 0; 0 0 1; 0 0.7 0; 0.5 0.5 0; 0.5 0 0.5; 0 0.5 0.5 ; 0.25 0.25 0.25 ; 0.5 0 0; 0 0.5 0; 0 0.5 0; 0.1 0.2 0.3; 0.3 0.2 0.1; 0.5 0.5 0.8; 0.1 0.8 0.1 ];

symbole=['o';'o';'o';'s';'^';'^';'p';'h';'p';'h';'+';'*';'>';'<';'v'] ;
bold=['none';'k   ';'none';'k   ';'none';'k   ';'none';'k   ';'k   ';'k   ';'none';'none';'none';'none'];

cla;
%e=matrix2saisir(X);
n=max(gr.d);

hold on;
%% coloration from the names 
[n1,p1]=size(D.i);
maxgroup=max(gr.d)

if(isfield(gr,'g'));
    D.i=gr.g.i(gr.d,:);
 else
     D.i=num2str(gr.d);
end
    
start_pos=1;
end_pos=size(D.i,2);
mycolor=create_group1(D,start_pos,end_pos);
mycolor.g.i
% if(nargin<=6);
%     mycolor.d=ones(n1,1);
% end


for k=1:maxgroup
   l=find(gr.d==k);
   %max(l)
   
   X=selectrow(D,l');
   X=selectcol(X,[i j]);
	G=mean(X.d);
	%%size(X.i,1)
   if(size(X.i,1)<3)
         continue;
   end
  if((pointPlot~=0)&(centroid_variability==0))
        [n1,p1]=size(X.d);
        for obs=1:n1
            h=plot(X.d(obs,1),X.d(obs,2),['k' symbole(mod(k+10,14-1)+1,:)],'MarkerSize',...
            cSizePoint,'MarkerFaceColor',couleur(mod(k,15)+1,:));
        end
  end
   
    res=pca(X);
	vec=res.eigenvec.d;
    l1=res.eigenval.d(1);
	l2=res.eigenval.d(2);
	t=0:0.01:2*pi;
 	n1=size(X.d,1);
    c=tinv(1-(confi/2),n1-1);
    if(centr_var==1); c=c/sqrt(n1);end
    x=c*sqrt(l1)*cos(t);y=c*sqrt(l2)*sin(t);
 	u=(vec(1)*x-vec(2)*y)+G(1,1);v=(vec(2)*x+vec(1)*y)+G(1,2);
 	h=plot(u,v);
    k1=mycolor.d(l(1));
    %if(nargin<6); k1=1;end
    %k1
    set(h,'Color',couleur(mod(k1,15)+1,:));
    set(h,'LineWidth',1.5)
    h=text(G(1,1),G(1,2),X.i(1,:),'Color',couleur(mod(k1,15)+1,:),'FontSize',csize);
    if((centr_var==0)&(pointPlot~=0))
        set(h,'BackGroundColor',[1 1 1]);
    end
    set(h,'Interpreter','none');
    %pause
end;
xlabel(D.v(i,:));
ylabel(D.v(j,:));
%plot(X(:,1),X(:,2),'+');
%carte_couleur1(D,i,j,4,4);
%hold on;


