function [saisir] = excel2saisir(filename,nchar,deb,xend)
%excel2saisir 	- reads an excel text file
%function [saisir] = excel2saisir(filename,(nchar),(start),(xend))
%
%Input arguments
%==============
%filename: (string) name of the text Excel file in .csv format
%nchar : (integer, optional) number of character kept in the identifiers
%(default : 20)
%start:(integer , optional) Index of the beginning of the observations to be loaded 
%xend:(integer , optional) Index of the final of the observations to
%be loaded (greater than start)
%
%Reads an Excel file which has been saved under the format .csv (the delimiters are ';')
%the excel file includes the identifers of rows and columns 
%deb : number of the first row decoded, xend: final row decoded 
%The Excel format is compulsorily the following (example):
%           varname1    varname2    varname3
%obsname1   number11    number12    number13
%obsname2   number21    number22    number23
%obsname3   number31    number32    number33
%
%The decimal separator is the point (".") NOT THE COMMA (",")
% Example of .csv format (3 rows named "obs1", "obs2", "obs3"; 3 columns named
% "var1", "var2", "var3")
% data : 
%=======================
%       var1  var2  var3
%obs1   1     2     3
%obs2   4     5     6
%obs3   7     8     9
%=======================
%The corresponding  .csv Excel file is: 
% ;var1;var2;var3
% obs1;1;2;3
% obs2;4;5;6
% obs3;7;8;9



filename=upper(filename);
if(isempty(findstr('.CSV',filename)))
   filename=[filename '.CSV'];
end
if(nargin<2) nchar=20;end;
if(nargin>2)
   data = readexcel1(filename,nchar,deb,xend);
else
   data = readexcel1(filename,nchar);
end;   
saisir = string2saisir(data);
[n,p]=size(saisir.d);
testrow=sum(isnan(saisir.d),2);
saisir=deleterow(saisir,testrow==p);% elimination of row formed of isnan
[n,p]=size(saisir.d);
testcol=sum(isnan(saisir.d));
saisir=deletecol(saisir,testcol==n);% elimination of row formed of isnan

