function res=leave_one_out_pls1(x,y,ndim);
%leave_one_out_pls1         - PLS1 with leave_one out validation
%function res=leave_one_out_pls1(X,y,ndim);
%
%Input arguments:
%===============
%X:SAISIR matrix of predictive variables (n x p)
%y:Saisir vector of the variable to be predicted (n x 1)
%ndim: (integer) maximal number of tested PLS dimensions
%
%Ouput arguments:
%===============
%res with fields
%predy: SAISIR matrix of predicted y in leave-one-out (n x ndim) for all
%the dimensions tested.
%rmse: Root mean square error (1 x ndim) for all the dimensions tested
%r2: r2 value between observed and predicted y for all the dimensions
%tested.
%optimal_error: (double) minimal rmse among all the dimensions tested.
%optimal_dim: (integer) PLS dimension giving the best model.
%optimal_r2: r2 value for the best model.
%
%The function leaves out one observation and makes a model with the
%resulting observations. The left observations is predicted.
%This procedure is carried out for the n rows in X.
%
%This function is very slow and must be used only for small data set
%(typically less than 30 observations). Otherwise one must prefer a
%validation procedure. 





[n,p]=size(x.d);
[n1,p1]=size(y.d);

for i=1:n
    disp([i n]);
    index=ones(n,1);
    index(i)=0;
    [x1, x2]= splitrow(x,index==1);
    [y1, y2]= splitrow(y,index==1);
    this_pls=basic_pls(x1,y1,ndim);
    aux=applypls(x2,this_pls);
    predy.d(i,:)=aux.PREDY.d;
end
predy.v=aux.PREDY.v;
predy.i=y.i;
res.predy=predy;

aux=y.d*ones(1,ndim);
aux=predy.d-aux;
rmse.d=sqrt(sum((aux.*aux))/n);
rmse.i='rmse from leave one out';
rmse.v=predy.v;
res.rmse=rmse;
cor=cormap(y,predy);
cor.d=cor.d.*cor.d; %% coefficients of determination
res.r2=cor;
%% proposed number of dim
[res.optimal_error res.optimal_dim]=min(rmse.d);
res.optimal_r2=max(cor.d);
