function res=leave_one_out_pls2(x,y,ndim);
%leave_one_out_pls2         - PLS2 with leave_one out validation
%function res=leave_one_out_pls2(X,y,ndim);
%
%Input arguments:
%===============
%X:SAISIR matrix of predictive variables (n x p)
%y:SAISIRr vector of the variables to be predicted (n x k)
%ndim: (integer) maximal number of tested PLS dimensions
%
%Ouput arguments:
%===============
%res with fields
%col: vector of k cells. The cell res.col{i} contains the y predicted values 
%(n x ndim) associated with the variable i, for all the PLS dimensions
%tested.
%RMSEV:root mean square error (k x ndim) for all the variables (rows) and all the
%dimensions (columns).
%r2: r2 values (k x ndim) for all the variables (rows) and all the
%dimensions (columns).
%
%The function leaves out one observation and makes a model with the
%resulting observations. The ys of the left observations are predicted.
%This procedure is carried out for the n rows in X.
%
%This function is very slow and must be used only for small data set
%(typically less than 30 observations). Otherwise one must prefer a
%validation procedure. 

[n,p]=size(x.d);
[n1,p1]=size(y.d);

for i=1:n
    disp([i n]);
    index=ones(n,1);
    index(i)=0;
    [x1, x2]= splitrow(x,index==1);
    [y1, y2]= splitrow(y,index==1);
    this_pls2=basic_pls2(x1,y1,ndim);
    for j=1:p1
        this_model=this_pls2.res{j};
        this_y=applypls(x2,this_pls2.res{j});
        col{j}.PREDY.d(i,:)=this_y.PREDY.d;%% does it work ?
    end
end

for j=1:p1;
    col{j}.PREDY.i=x.i;
    col{j}.PREDY.v=num2str((1:ndim)');
    col{j}.name=y.v(j,:);
end
res.col=col;

for j=1:p1;
    this_y=col{j}.PREDY;
    %this_y
    obs_y=selectcol(y,j);
    cor=cormap(this_y,obs_y);
    delta=this_y.d-obs_y.d*ones(1,ndim);
    rmsec.d(j,:)=sqrt((sum(delta.*delta))/n);
    r2.d(j,:)=cor.d.*cor.d;
end
rmsec.i=y.v;
rmsec.v=num2str((1:ndim)');
r2.i=y.v;
r2.v=num2str((1:ndim)');
res.RMSEV=rmsec;
res.r2=r2;