function[discrtype]=maha(saisir,group,maxvar)
%maha 	- simple discriminant analysis forward introducing variables no validation samples 
%function[res]=maha(X,group,maxvar)
%
%Input arguments:
%----------------
%X      :SAISIR matrix (n x p) of predictive variables
%group  :SAISIR vector (n x 1) of integers indicating the group. Two observations 
%belonging to the same group have the same group number
%maxvar : integer indicating the maximum number of variables to be
%introduced.
%
%Output arguments:
%-----------------
%res with fields:
%   step with fields
%       index: vector of integers (1 x maxvar) giving the indices of the
%       selected variables
%       correct: vector of integer ( 1 x maxvar) giving the number of
%       correct classifications at each step 
%       name: identifiers of the introduced variables (matrix of char with
%       maxvar rows)
%   classed: predicted groups in the final step (SAISIR vector of integers
%   n x 1)
%
%The function assesses a simple quadratic discriminant analysis introducing
%up to maxvar variables
%At each step, the more discriminating variable (according to the percentage of correct
%classification) is introduced. Only forward
%The function makes use of matlab function "classify"

[nrow ncol]=size(saisir.d);
selected=zeros(1,ncol);
bestchoice=[];
for introduced=1:maxvar
   bestcorrect=0;
   for col=1:ncol
      if(selected(1,col)==0)
         currentchoice=[bestchoice;col];
         classed=classify(saisir.d(:,currentchoice),saisir.d(:,currentchoice),group.d);
			ncorrect=sum(classed==group.d);      
      	if(ncorrect>bestcorrect)
         	bestcorrect=ncorrect;
         	candidate=col;
      	end;   
   	end;      
   end;
   step.index(introduced)=candidate
   step.correct(introduced)=bestcorrect
   step.name(introduced,:)=saisir.v(candidate,:);
   selected(1,candidate)=1;
	bestchoice=[bestchoice;candidate];   
end;
discrtype.step=step;
discrtype.classed.d=classed;
discrtype.classed.i=saisir.i;
discrtype.classed.v='predicted group'
