function [saisir] = mdistance(saisir1,saisir2,metric)
%mdistance 			- computes distances between the two tables using metric "metric"
%function dis = mdistance(X1,X2,metric)
%
%Input arguments:
%================
%X1: SAISIR matrix ( n1 x p)
%X2: SAISIR matrix (n2 x p)
%metric: SAISIR matrix (p x p) of the metric
%
%Output argument:
%================
%dis: SAISIR matrix of distances between observations (n1 x n2) according to the metric "metric"
%
%example of use (computing Mahalanobis distances):
%================================================
%data=matrix2saisir(rand(50,10));%% dummy data
%data1=center(data);%% centered data 
%metric=matrix2saisir(inv(data1.d'*data1.d));
%dis=mdistance(data1,data1,metric);%% Mahalanobis distance between
%%observations

[nrow1 ncol1]=size(saisir1.d);
[nrow2 ncol2]=size(saisir2.d);
if(ncol1~=ncol2); error('The number of columns must be equal');end
aux=ones(nrow1,1);
saisir.d=zeros(nrow1,nrow2);
for i2=1:nrow2
%    if(mod(i2,500)==0)
%        disp(format1(i2,'of',nrow2));
%    end
  delta=(saisir1.d-aux*saisir2.d(i2,:));
   aux1=delta*metric.d;
   delta=(aux1.*delta)';
   saisir.d(:,i2)=sqrt(sum(delta,1));%% pour essai
   %saisir.d(:,i2)=sum(delta,1); 
end
saisir.i=saisir1.i;
saisir.v=saisir2.i;
   