function x = moving_average(saisir1,window_size)
%moving_average   - Moving average of signals
%function X1=moving_average(X,window_size)
%
%Input arguments
%===============
%X:SAISIR matrix of data (normally digitized signals such as spectra)
%window_size: integer giving the number of data points which are locally
%averaged (odd number).
%
%Ouput arguments
%===============
%X1: matrix of averaged data
%
%The function replaces a given variable by its average in the range defined
%by "window_size".
%(window_size-1)/2 variables are lost at the begining and the end of the signal. 
%
%For example with window_size = 5
%a given variable x(i) of index i is replaced by the local average 
%(x(i-2)+x(i-1)+x(i)+x(i+1)+x(i+2))/5  
if(mod(window_size,2)==0)
    error('Window_size must be an odd number');
end
[n,p1]=size(saisir1.d);
gap=ceil(window_size/2);
%first: smoothing the data
x=saisir1.d(:,1:(p1-window_size+1));
for i=2:window_size
    x=x+saisir1.d(:,i:(p1-window_size+i));
end
aux=x/window_size;
clear x;
x.d=aux;
x.i=saisir1.i;
x.v=saisir1.v(gap:(p1-gap+1),:);