function[pcatype]=normed_pca(saisir)
%normed_pca			- PCA with normalisation of data
%function[pcatype]=normed_pca(X)
%function [pcatype]=pca(X,(var_score))
%Assesses principal component analysis (on not normalised data)
%
%Input arguments:
%---------------
%X: SAISIR matrix
%
%Output arguments:
%----------------
%pcatype with fields:
%score      :PC score
%eigenvec   :eigenvectors (loadings)
%eigenval   :eigenvalues
%average    :average observation 
%var_score  :scores of the variables
%std: standard deviations of the columns of X

%NOTA       :the weight of the observations are equal to 1/(number of rows)   
%           ALL the possible scores are calculated
%
%SEE ALSO   : pca, cumulate_covariance, covariance_pca, normed_pca
%correlation plot, apply_pca
%
%%typical example:
%%===============
%p=normed_pca(data);%% PCA
%map(p.score,1,2);%% PC plot 1-2
%figure;
%correlation_plot(p.score,1,2, data);%% correlation with chemistry



std1=std(saisir.d);
aux=(1./std1);
saisir.d=saisir.d.*(ones(size(saisir.d,1),1)*aux);
pcatype=pca(saisir,1);
pcatype.std.d=std1;
pcatype.std.i='standard deviation';
pcatype.std.v=saisir.v;

%[n,p]=size(saisir.d);
%for i=1:n
%   for j=1:p;
%      saisir.d(i,j)=saisir.d(i,j)/std1(j);
%   end
%end
% eigenval.d=pcatype.eigenval.d;
% eigenvec.d=pcatype.eigenvec.d;
% pcatype.var_score.d=diag(sqrt(abs(eigenval.d)))*eigenvec.d;
% pcatype.var_score.i=pcatype.eigenvec.i;
% pcatype.var_score.v=saisir.v;