function[res]=pca_cross_ridge_regression(x,y,range,selected)
%pca_cross_ridge_regression	- PCA ridge regression with crossvalidation 
%function[res]=pca_cross_ridge_regression(X,y,krange,selected)
%
%Input argument:
%==============
%X: SAISIR matrix (n x p) of predictive variables
%y: SAISIR vector (n x 1) of the variable to be predicted 
%range: MATLAB vector of integers (1 x q)
%selected: MATLAB vector (n x 1) with elements = 0 (selected in
%calibration)
%or 1 ( selected in validation)
%
%Outut argument:
%==============
%res with fields:
%predy: predicted y in the validation set (q columns)
%obsy: observed y of the validation set (1 column)
%r2: r2 between observed and predicted values in the validation set 
%(vector with q elements)
%rmsecv: root mean square error of validation (1 x q)
%ridgetype: calibration model (see function "pca_ridge_regression")
%
%This function divides a collection in calibration and verification set
%using the input argument "selected"
%and applies the pca_ridge_regression on the validation set
%
% The function calculates as many ridge regression models as the number of
% elements in "range"
% In ridge regression, the product X'X is replaced by X'X +kI.
% In the present function, k is in fact the eigenvalue of the corresponding PCA component
% for example, if krange = [1 3 5], that means that the tested values of k
% are the eigenvalues #1, #3, #5.
% The rationale of this, is that k in ridge_regression is very difficult to find
% it is a good idea to test a value in the range of the observed eigenvalues
%
%Typical example
%===============
%%Let DATA (n x p) be the SAISIR matrix of predictive variables and y (n x 1) the variable to be predicted.
%myrange=1:20 %% testing the eigenvalues from 1 to 20
%sel=random_select(size(DATA.d,1), round(DATA.d,1/3));%% 1/3 in validation
%[res]=pca_cross_ridge_regression(DATA,y,1:10,sel);%% testing the 10 first
%%eigenvalues
%xy_plot(res.predy,10, res.obsy,1);%% display of the 10th model
%
%
%%See also: pca_ridge_regression, ridge_regression, ridge_regression1,
% apply_ridge_regression

%nind=size(x.d,1);
%nend=sum(selected);

[xval, xcal]=splitrow(x,selected==1);
[yval, ycal]=splitrow(y,selected==1);
pcatype=pca(xcal);
%'[ridgetype]=pca_ridge_regression(pcatype,ycal,range);'
[ridgetype]=pca_ridge_regression(pcatype,ycal,range);
%'res1=apply_ridge_regression(ridgetype, xval,yval);'

res1=apply_ridge_regression(ridgetype, xval,yval);

res.predy=res1.predy;
res.obsy=yval;   
res.r2=res1.r2;
res.rmsecv=res1.rmsecv;
res.ridgetype=ridgetype;