function[res]=pcr1(x,y,dim)
%pcr1		- Basic model of PCR (components introduced in the order of eigenvalues)
% function [pcrtype]=pcr1(X,y,dim)
%
%Input arguments:
%===============
%X: SAISIR matrix (n x p) of predictive data
%y: SAISIR matrix (n x k) of variables to be predicted (k variables)
%dim: (integer) dimension of the model
%
%Output argument
%===============
%pcrtype with fields:
%pca: result of pca applied on X (see function "pca")
%beta: coefficients of the models (p x k) obtained with "dim" dimensions
%averagex: average of x (1 x p)
%averagey: average of y (1 x k)
%info: 'predicting several y  with xxx dimensions'
%r2: determination coefficient for the ys (1 x k)
%predy: predicted y (n x k).
%
%This function makes models for all the ys which are in "y" . The models
%are built only with "dim" dimensions.
%
%See also : pcr (only one y, but the dimensions are scanned),apply_pcr



mypca=pca(x);
nind=size(y.d,1);
ny=size(y.d,2);
averagey=mean(y.d);
centredy=y.d-ones(nind,1)*averagey;
c=mypca.score.d(:,1:dim);
v=1./mypca.eigenval.d(:,1:dim);
v=diag(v);
beta1=v*c'*centredy;% this beta from PCA scores
beta.d=mypca.eigenvec.d(:,1:dim)*beta1;% this beta from original centred data
predy.d=c*beta1+ones(nind,1)*averagey;
predy.i=x.i;
predy.v=y.v;
beta.i=x.v;
beta.v=y.v;
res.pca=mypca;
res.beta=beta;
res.averagex=mypca.average;
res.averagey.d=averagey;
res.averagey.i='y averages';
res.averagey.v=y.v;
res.info=['predicting several y  with ' num2str(dim) ' dimensions'];
aux=corrcoef([y.d predy.d]);
for i=1:ny
   corr.d(1,i)=aux(i,i+ny);
end;   
corr.v=y.v;
corr.i='r2';
res.r2=corr;
res.r2.d=res.r2.d.*res.r2.d;%% ugly patch 
res.predy=predy;