function quaddis_type=quaddis(x,g);
%quaddis        - Quadratic discriminant analysis 
%function quadis_type=quaddis(x,group);
%Quadratic discriminant analysis
%(Training) 
% A multinormal distribution is assumed in each qualitative group 
% ===============================================================
% Input args:
%============
% x:        predictive data set (matrix n x p)
% g:        qualitative groups (matrix n x 1) with integer ranging from 1
% to maximum number of groups (gmax) 
%
% Output args:
%============
% quaddis_type with fields:
% ncorrect100: percentage of correct classification (number)
% confus    : confusion matrix (gmax x gmax)
% mean      : means according to each group (gmax x p)
% predgroup : predicted groups (integer) (n x gmax)
% density   : pseudo-densities of each observation (n x gmax)
% proba     : probability of belonging to a given group (n x gmax)
%
% model     : predictive model with fields:
%   inv:    Matlab matrices of Mahalanobis metrics (cube p x p x gmax)   
%   Mut:    Matlab matrices of means according to each group (gmax x p)
%   det:    Matlab vector of determinants of covariance matrices of each
%   group (1 x gmax) 
%See also apply_quaddis, crossval_quaddis 

%From a source of Michel Semenou 13 11 2006 
small=10^(-20);
[nind,nvar]=size(x.d);


Tcla=max(g.d);%% number of groups
%% Creations of covariance matrices and their inverse
for t=1:Tcla
        U=x.d((g.d==t),:);%% matrices of the class t
        Mut(t,:)=mean(U);
        Matcovt(:,:,t)=cov(U);
        xdet(t)=det(Matcovt(:,:,t))+small;
        xinv(:,:,t)=pinv(Matcovt(:,:,t));
end;
for i=1:nind
    x1=x.d(i,:);
    for t=1:Tcla
        Densite(i,t)=(1/(((2*pi).^((nvar)/2))*(xdet(t).^0.5)))*exp(-0.5*(x1-Mut(t,:))*xinv(:,:,t)*(x1-Mut(t,:))');
    end;
    Zht(i,:)=Densite(i,:)./sum(Densite(i,:));%% probability of belonging to a given class
end;
%Zht
[Y,I]=max(Zht');
Zhtclass=I';

res.predgroup.d=Zhtclass;
res.predgroup.i=x.i;
res.predgroup.v='predicted groups';

res.density=matrix2saisir(Densite);;
res.density.i=x.i;
res.proba=matrix2saisir(Zht);
res.proba.i=x.i;

if(isfield(g,'g'))
    quaddis_type.confus.i=addcode(g.g.i,'observed-');
    quaddis_type.confus.v=addcode(g.g.i,'predicted-');
    quaddis_type.density.v=g.g.i;
    quaddis_type.proba.v=g.g.i;
    quaddis_type.mean.i=g.g.i;
end

confus=zeros(Tcla,Tcla);
for i=1:nind
    confus(g.d(i),Zhtclass(i))=confus(g.d(i),Zhtclass(i))+1;
end
confus=matrix2saisir(confus);
ncorrect=sum(diag(confus.d));
xmean=matrix2saisir(Mut);
xmean.v=x.v;
quaddis_type.ncorrect100=ncorrect/nind*100;
quaddis_type.confus=confus;
quaddis_type.mean=xmean;
quaddis_type.predgroup.d=Zhtclass;
quaddis_type.predgroup.i=x.i;
quaddis_type.predgroup.v='predicted groups';
quaddis_type.density=matrix2saisir(Densite);;
quaddis_type.density.i=x.i;
quaddis_type.proba=matrix2saisir(Zht);
quaddis_type.proba.i=x.i;
if(isfield(g,'g'))
    quaddis_type.confus.i=addcode(g.g.i,'observed-');
    quaddis_type.confus.v=addcode(g.g.i,'predicted-');
    quaddis_type.density.v=g.g.i;
    quaddis_type.proba.v=g.g.i;
    quaddis_type.mean.i=g.g.i;
end

model.inv=xinv;%% keeping the metric matrices 
model.Mut=Mut;%% keeping the average of each class
model.det=xdet;%% keeping the determinant of each class
quaddis_type.model=model; %% to keep the calibration model



