function[selected]=random_select(nel, nselect,nrepeat)
%random_select     - bulding a vector of random elements 0 or 1
%function[selected]=random_select(nel, nselect, (nrepeat))
%
%Input arguments:
%===============
%nel: (integer) number of elements in the output vector "selected"
%nselect: (integer smaller than nel) number of elements taking the value 1
%nrepeat: (integer, optional) number of consecutive replicates.
%Output arguments:
%
%===============
%selected: MATLAB vector with nel elements equal to 1 or 0
%
% This function builds up a MATLAB vector of nel elements with nselect
% elements equal to 1 in random position, and (nel-nselect) equal to 0.
% nrepeat (optional) randomly selects nselect values, but organised by block of nrepeat groups 
% For example, if nrepeat =3 a possible result is [0 0 0 1 1 1 0 0 0 1 1 1 1 1 1 ...]
%
% This function is useful for dividing a collection into two sets, for 
% example in many functions of SAISIR allowing a validation test.
% The case with "nrepeat" defined corresponds to the situation in which the
% replicates are in equal numbers and consecutive in the data collection.
%
%Typical use: randomly building a calibration and validation set
%==============================================================
%[n,p]=size(DATA.d);
%sel=random_select(n,round(n/3));%% A third in validation
%cal=selectrow(DATA,sel==0);%% building the calibration set
%val=selectrow(DATA,sel==1);%% building the validation set
%
%See also: random_splitrow
%
nel=round(nel);
nselect=round(nselect);
selected=zeros(1,nel);
if(nargin<3)
   found=0;
    aux=randperm(nel);
    aux=aux(1:nselect);
    selected(aux)=1;
% 	while found<nselect
% 		number=uint32(random('Uniform',1,nel)+0.5);
%    	%number
%    	if(selected(1,number)==0)
% 			selected(1,number)=1;
%       	found=found+1;
%    	end;   
	
else
   nel1=floor(nel/nrepeat);
   selected1=zeros(1,nel1)
   found=0;
   nselect1=floor(nselect/nrepeat);
   while found<nselect1
		number=uint32(random('Uniform',1,nel1)+0.5);
   	%number
   	if(selected1(1,number)==0)
			selected1(1,number)=1;
      	found=found+1;
   	end;   
	end;
   for i=1:nel1
      if(selected1(1,i)==1)
         for j=1:nrepeat
         selected(1,(i-1)*nrepeat+j)=1;   
         end
      end
   end
end   
