function res=regression_score(x,beta,y)
%regression_score       - build a factorial space for regression
%function res=regression_score(x,beta,(y))
%------------------
%Input arguments: 
%===============
%x      : data matrix (n x p)
%beta   : vector of regression coefficients (p x 1)
%y      :(optional) known y value
%
%Output argument:
%===============
%res with fields
%score  : regression scores (also y split)
%reconstructed_norm2: squared norms of the scores
%cumulated_norm2: cumulated squared norms of the scores
%projector: matrix such as score=x*projector
%eigenvec_sum: sum of the eigenvectors of PCA (linked to the theory)
%xmean: mean of x
%r2   : if (y defined) r2 of the cumulated model  
%
%Given a data matrix x and the regression coefficients beta,
%the function build up a matrix of orthogonal scores 
%such as predicted y is equal to the sum of this scores 
%The scores can be used to examine the observations "oriented" in the
%prediction of y. 
%As the scores are ranked as a function of their ability to predict y,
%It is possible to examine the observations beginning by the first scores.

epsilon=10^(-20);%% very small number 
[regx xmean]=center(x);
regx.d=x.d*diag(beta.d);
preg=pca(regx); %%% Here is the idea !!!
s=sum(preg.eigenvec.d); 
[n,p]=size(preg.score.d);
splity=sqrt(n)*preg.score.d*diag(s);
ynorm2=sum(splity.*splity);
ynorm2=ynorm2/sum(ynorm2)*100;
[ynorm2 index]=sort(-ynorm2);
ynorm2=-ynorm2;
cynorm2=cumsum(ynorm2,2);
splity=splity(:,index);%% ranked splitted y
s=s(index);
projector=diag(beta.d)*preg.eigenvec.d(:,index)*diag(s);
res.score.d=splity;
res.score.i=x.i;
[n,p]=size(preg.score.d);
res.score.v=num2str((1:p)');

res.reconstructed_norm2.d=ynorm2;
res.reconstructed_norm2.i='reconstructed squared norm of predicted y';
res.reconstructed_norm2.v=res.score.v;

res.cumulated_norm2.d=cynorm2;
res.cumulated_norm2.i='reconstructed cumulated squared norm of predicted y';
res.cumulated_norm2.v=res.score.v;

res.projector.d=projector;
res.projector.i=x.v;
res.projector.v=res.score.v;

res.eigenvec_sum.d=s;
res.eigenvec_sum.i='sum of the elements of PC eigenvectors';
res.eigenvec_sum.v=res.score.v;
res.xmean=xmean;
if(nargin>2)%% observed y given 
    aux=cormap(y,res.score);
    aux.d=aux.d.*aux.d;
    res.r2.d=cumsum(aux.d);
    res.r2.v=res.score.v;
    res.r2.i='r2 Yobserved/predicted (cumulated)';
end
aux=preg.eigenval.d<epsilon;
if(sum(aux)>0)
xdisp('Warning!', sum(aux), ' scores with eigenvalues less than ',epsilon,' as been removed');

if(nargin>2)
res.r2=deletecol(res.r2,aux);%% avoiding processing dummy scores
end;
res.score=deletecol(res.score,aux);
res.reconstructed_norm2=deletecol(res.reconstructed_norm2,aux);
res.cumulated_norm2=deletecol(res.cumulated_norm2,aux);
res.projector=deletecol(res.projector,aux);
res.eigenvec_sum=deletecol(res.eigenvec_sum, aux);
end;

%% verification of projectors
% % x=center(x);
% % aux=x.d*projector;
% % delta=aux-res.score.d;
% % test=sum(sum(delta.*delta))/sum(sum(aux.*aux));
% % xdisp(test, ' is close to zero');
%% this is verified 
