function[ridgetype]=ridge_regression(x,y,krange)
%ridge_regression		- Basic ridge regression
% function [ridgetype]=ridge_regression(X,y,krange)
%
%Input arguments:
%===============
%X: SAISIR matrix of predictive variables (n x p)
%y: SAISIR vector of observed y (n x 1)
%krange: MATLAB vector of k-values to be tested in the ridge regression
%
%Let ntest = length(krange)
%
%Output argument:
%===============
%ridgetype with fields
%beta: beta coefficients associated with th ntest k-values as defined in "krange"
%averagex: average of X
%averagey: average of y
%rmsec: Root mean square error of calibration (ntest x 1 )
%predy: predicted y for each test k-value (n x ntest)
%r2: r2 for each tested k-value (ntest x 1); 



% return as many beta as the number of elements in krange

[n,p]=size(x.d);
meanX=mean(x.d);
meanY=mean(y.d);
X=x.d-ones(n,1)*meanX;
Y=y.d-ones(n,1)*meanY;
tmp=X'*Y;% avoiding assessing that each time
XpX=X'*X;
iter=0;
for k=krange
   iter=iter+1;
   %disp(iter);
   %disp(k);
   beta(:,iter)=inv((XpX+k*eye(p)))*tmp;
   %beta(:,iter)=pinv((XpX+k*eye(p)))*tmp;
   predy(:,iter)=X*beta(:,iter)+meanY;   
   tmp1=predy(:,iter)-y.d;
   rmsec(iter)=sqrt(sum(tmp1.*tmp1)/n);
   xdisp('RMSE = ', rmsec(iter));   
end
ridgetype.beta.d=beta;
ridgetype.beta.i=x.v;
ridgetype.beta.v=num2str(krange');

ridgetype.averagex.d=meanX;
ridgetype.averagex.i='Average of X';
ridgetype.averagex.v=x.v;

ridgetype.averagey.d=meanY;
ridgetype.averagey.i='Average of Y';
ridgetype.averagey.v=y.v;

ridgetype.rmsec.d=rmsec;
ridgetype.rmsec.v=num2str(krange');
ridgetype.rmsec.i='root mean square sum of square';

ridgetype.predy.d=predy;
ridgetype.predy.v=num2str(krange');
ridgetype.predy.i=x.i;

corr.d=zeros(1,iter);
for i=1:iter
   aux=corrcoef(y.d,predy(:,i));
   ridgetype.r2.d(1,i)=aux(1,2)*aux(1,2);
end;   
ridgetype.r2.i='r2';
ridgetype.r2.v=num2str(krange');



