function[ridgetype]=ridge_regression1(x,y,normrange)
%ridge_regression1		- Basic ridge regression at a given norm
% function [ridgetype]=ridge_regression1(X,y,normrange)
% ONLY ONE VARIABLE TO BE PREDICTED (scan the dimensions)
% return as many beta as the number of elements in krange
%
%  Input arguments:
%  ===============
%  X: SAISIR matrix of predictive variables (n x p)
%  y: SAISIR vector of observed y (n x 1)
%  normrange: tested range of norms of beta (MATLAB vector of positive doubles)
%  
%  Let ntest = length(krange)
%  
%  Output argument:
%  ===============
%  ridgetype with fields
%  beta: beta coefficients associated with th ntest k-values as defined in "krange"
%  averagex: average of X
%  averagey: average of y
%  rmsec: Root mean square error of calibration (ntest x 1 )
%  predy: predicted y for each test k-value (n x ntest)
%  r2: r2 for each tested norm of beta (ntest x 1); 
%  k : MATLAB vector of resulting k values (ntest x 1)
%  expected norm: MATLAB vector of expected norms (copy of normrange)
%
% This function carried out as many ridge regressions  as the number of
% elements in "normrange".
%Rather that (as usual) trying to find the k-value of ridge, here, it is
%directly the norm of the regression coefficients beta which are the
%adjusted value. To each norm, there is a corresponding value of k.
%
%%Typical example:
%%===============
%ridgetype=ridge_regression1(X,y,[100, 200]);
%The function displays the Ordinary Least Square norm of beta 
%%"OLS norm = 1234.5678"
%%This value gives the maximum possible value of the norm
%%For example, testing half this norm 
%ridgetype=ridge_regression1(X,y,(1234.5678/2);
%
%See also: ridge_regression

global unorm;
global beta0;
global testednorm;
global yC;
global eigv;
[n,p]=size(x.d);
meanX=mean(x.d);
meanY=mean(y.d);
X=x.d-ones(n,1)*meanX;
Y=y.d-ones(n,1)*meanY;
p=pca(x);
V=p.eigenvec.d;%% eigenvector
C=p.score.d*sqrt(n);% this correction due to the weights in PCA function
eigv=p.eigenval.d*n;%% as column-vector
L=diag(1./eigv);

%% Here correct verification =================
beta1=L*C'*Y;%% applicable to C
% ypred=C*beta1;
% delta=Y-ypred;
% disp(sum(delta.*delta));
beta=V*beta1;%% applicable to X
% ypred=X*beta;%
% delta=Y-ypred;
% disp(sum(delta.*delta));
%% ============================================
maxnorm=beta'*beta;%% squared 
disp(['OLS norm = ' num2str(sqrt(maxnorm))]);
yC=Y'*C;
m=0;
aux1=length(normrange);
for testednorm=(normrange.*normrange);
    k = fzero(@xfun,[0 maxnorm]);
    m=m+1;
    xdisp(m, 'among',aux1);
    aux=ridge_regression(x,y,k);
    aux.k=k;
    aux.expected_norm=sqrt(testednorm);
    ridgetype(m)=aux;
end

% % function computing k at 0 values
function f = xfun(k)
global yC;%y'*C (to avoid comuting again
global testednorm;%% squared tested norm
global eigv;% eigenvalues of X'X
L=diag(1./(eigv+k));%% here a ridge regression on PCA components
this_norm=yC*L*L*yC';
f=this_norm-testednorm;%% must be zero for the correct value of k
