function [x1,emsc_model1,coefficients1]=saisir_emsc(x,good_spectra,bad_spectra,reference);
%saisir_emsc            - Correction of spectra by EMSC
%[X1, emsc_model, coefficients]=saisir_emsc(X,good_spectra,bad_spectra,ref);
%
%Input arguments:
%===============
%X              - Saisir matrix to be corrected
%good_spectra   - Spectra wich participate to the spectral reconstruction ,
%bad_spectra    - spectra not participating to the reconstruction
%ref            - reference spectrum to also assess the scattering effect
%(defaut : average);
%This argument can be replaced by [],if not present,but are not optional ! 
%
%Output arguments:
%===============
%X1             - Corrected spectra
%emsc_model     - Pure signals involved in the EMSC model 
%coefficients   - Regression coefficients associated to the pure signals
%
%Extended Multiplicative Signal Correction


%% Building the EMSC model 
[n,p]=size(x.d);
if(nargin>3)
    if(isempty(reference))
        emsc_model(1,:)=mean(x.d);
    else
        emsc_model(1,:)=reference.d;% reference spectra
    end
else
    emsc_model(1,:)=mean(x.d);
end

emsc_model(2,:)=ones(1,p);%baseline spectra
emsc_model(3,:)=(1:p)-p/2;%linear spectra
emsc_model(4,:)=emsc_model(3,:).*emsc_model(3,:);
start_good=5;
end_good=5;
n_good=0;
n_bad=0;
names=char({'Reference';'Constant';'Linear';'Quadratic'});

if(~isempty(good_spectra))
    emsc_model=[emsc_model;good_spectra.d];
    end_good=size(emsc_model,1);
    names=char({names good_spectra.i});
    n_good=size(good_spectra.d,1);
end
start_bad=end_good+1;
if(~isempty(bad_spectra))
    emsc_model=[emsc_model;bad_spectra.d];
    names=char({names bad_spectra.i});
    n_bad=size(bad_spectra,1);
end
end_bad=size(emsc_model,1);

%% Normalization of every body (is that justified) ? 
xnorm=sqrt(sum(emsc_model.*emsc_model,2));
reference_norm=xnorm(1);
emsc_model=emsc_model./(xnorm*ones(1,p));

%% assessing the parameter 
coefficients = (lscov(emsc_model',x.d'))';
size(coefficients)
if(~isempty(bad_spectra))
    bad_coeff=coefficients(:,1:4);
    bad_emsc=emsc_model(1:4,:);
else
    bad_coeff=coefficients(:,[1:4 start_bad:end_bad]);
    bad_emsc=emsc_model([1:4 start_bad:end_bad],:);
end
%% correcting the spectra 

x1.d=x.d-bad_coeff*bad_emsc;
x1.d=x1.d./((coefficients(:,1)*(ones(1,p))*reference_norm));% scatter effect
x1.i=x.i;
x1.v=x.v;

emsc_model1.d=emsc_model;
emsc_model1.v=x.v;
emsc_model1.i=names;
emsc_model1.n_good=n_good;
emsc_model1.n_bad=n_bad;

coefficients1.d=coefficients;
coefficients1.i=x.i;
coefficients1.v=names;

