function[plstype]=saisirpls(x,y,ndim)
%saisirpls 			- PLS regression with "dim" dimensions
%function [plstype]=saisirpls(X,Y,dim)
%
%Input arguments
%===============
%X: SAISIR matrix of predictive data (n x p)
%Y: SAISIR matrix of variables to be predicted (n x k)
%ndim: (integer) number of dimensions asked
%
%Ouput arguments
%===============
%plstype with fields
%beta: regression coefficients of the model (p x k)
%beta0: intercept of the models (1 x k)
%predy: predicted values (n x k)
%T: PLS scores of the PLS2 regression model (n x ndim)
%correlation: correlation coefficient (1 x k)
%
%This function assesses a pls2 model 
%Several variables can be predicted, but only ndim dimensions are tested
%
%Preferably uses basic_pls or basic_pls2
%
%%Typical example
%%===============
%Let DATA be dimensionned (n x p)
%Let Y be dimensionned (n x k)
%plstype=saisirpls(DATA,Y,10);
%%Assesses the models with 10 dimensions for the k variables in Y

mx=mean(x.d);
xc = x.d-ones(size(x.d,1),1)*mx;
my=mean(y.d);
yc=y.d-ones(size(y.d,1),1)*my;
%function[b]  = pls1a(X,y,K)
[beta.d,ypred,t.d]=pls(xc,yc,ndim);
%beta.d=pls1a(xc,yc,ndim);
beta.i=x.v; beta.v= y.v;
beta0.d=-mx*beta.d+my; % intercept
beta0.v=y.v;beta0.i='beta0';
predy.d= x.d*beta.d+ones(size(x.d,1),1)*beta0.d;
predy.i=x.i;
predy.v=y.v;

plstype.beta=beta;
plstype.beta0=beta0;
plstype.predy=predy;
t.i=x.i;
for i=1:ndim
   chaine=['t' num2str(i) '             '];
   %eigenvec.v(i,:)=chaine(1:6);
 	t.v(i,:)=chaine(1:10);
end
plstype.T=t;
co=cormap(y,predy);
co.d=diag(co.d)';
co.v=y.v;
co.i='Correlation coefficients';
plstype.correlation=co;