function[Q, saliences, explained, SingVal]=xcomdim_v5(table,threshold,ndim)
%xcomdim_DNR				- Finding common dimensions in multitable data
% No direct use. Normally called with function "comdim"
%
% function[Q, saliences, explained]=xcomdim_DNR(col,threshold,ndim)
%
% Finding common dimensions in multitable according to method 'level3' 
% proposed by E.M. Qannari, I. Wakeling, P. Courcoux and H. J. H. MacFie
% in Food quality and Preference 11 (2000) 151-154
%
% table is an array of matrices with the same number of row
% threshold (optional): if the difference of fit<threshold then break the iterative loop 
% ndim : number of common dimensions
% default: threshold=1E-10; ndim=number of tables
% returns Q: nrow x ndim the observations loadings
%
if(nargin<2)
   threshold=1E-10;
end;   
ntable=size(table,2);
if(nargin<3)
   ndim=ntable;
end;   
nrow=size(table{1},1) ; 

LAMBDA=zeros(ntable,ndim);
Q=zeros(nrow,ndim);

% centring and rescaling the tables ***************************
for(i=1:ntable)

   X=table{i};
   average=mean(X);
   toto=ones(nrow,1)*average;
   size1=size(X);
   size2=size(toto);
   
   if size1~=size2
       error('All data tables must have the same number of rows !!!')
   end

   table{i}=X-ones(nrow,1)*average;
   aux=table{i};
   xnorm=sqrt(sum(sum(aux.*aux)));

   table{i}=table{i}/xnorm;
end;

Lambda_Temp=[];
unexplained=ntable; % Warning!: true only because the tables were set to norm=1

for dim=1:ndim
    previousfit=10000;
    lambda=ones(ntable,1);
    deltafit=1000000;

    while(deltafit>threshold)
        W_mat=zeros(nrow,nrow);
        
        for ta=1:ntable
            temp=table{ta}*table{ta}';
            W_mat=W_mat+lambda(ta)*temp;
        end

        [UW, SW, VW]=svd(W_mat);
        
        if abs(min(UW(:,1)))>abs(max(UW(:,1)))
            UW(:,1)=-UW(:,1);
        end

        q=UW(:,1);

        fit=0;
        for ta=1:ntable
            % estimating residuals
            temp=table{ta}*table{ta}';
            lambda(ta)=q'*temp*q;

            aux=temp-lambda(ta)*q*q';

            fit=fit+sum(sum(aux.*aux));
        end
        
        Lambda_Temp=[Lambda_Temp,lambda];
        
        deltafit=previousfit-fit;
        previousfit=fit;
    end %deltafit>threshold

    explained(dim)=(unexplained-fit)/ntable*100;
    unexplained=fit;
    
    LAMBDA(:,dim)=lambda;
    Q(:,dim)=q;
    SingVal(1,dim)=SW(1,1); % DB, 13.03.2014
    
    % updating residuals
    aux=eye(nrow,nrow)-q*q';
    
    for ta=1:ntable
        table{ta}=aux*table{ta};
    end
end

saliences=LAMBDA;